# 安全

NVIDIA 致力于软件产品和服务的安全与信任，包括我们组织管理的所有源代码仓库。

如需报告安全问题，请使用下方指定的联系方式。**请勿通过 GitHub 报告安全漏洞。**

## 报告 NVIDIA 产品潜在安全漏洞

如需报告 NVIDIA 产品的潜在安全漏洞：

- 网页：[安全漏洞提交表单]

[https://www.nvidia.com/object/submit-security-vulnerability.html](https://www.nvidia.com/object/submit-security-vulnerability.html)

- 邮箱：[psirt@nvidia.com](mailto:psirt@nvidia.com)

- 建议使用以下 PGP 密钥进行安全邮件通信：[NVIDIA 公共 PGP 密钥](https://www.nvidia.com/en-us/security/pgp-key)

- 请包含以下信息：
- 产品/驱动名称及版本/分支
- 漏洞类型（代码执行、拒绝服务、缓冲区溢出等）
- 漏洞复现步骤
- 漏洞利用或概念验证代码
- 漏洞可能影响，包括攻击者如何利用该漏洞

NVIDIA 目前尚无漏洞赏金计划，但在根据协调漏洞披露政策解决外部报告的安全问题时会予以致谢。详情请访问 [产品安全事件响应团队 (PSIRT) 政策页面](https://www.nvidia.com/en-us/security/psirt-policies/)。

## NVIDIA 产品安全

所有安全相关问题请访问 NVIDIA 产品安全门户：

[https://www.nvidia.com/en-us/security](https://www.nvidia.com/en-us/security)
